==> instancio-core-3.7.1-sources.jar: org/instancio/internal/context/TargetSelectorSelectorMap.java <==
/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.instancio.internal.context;

import org.instancio.TargetSelector;
import org.instancio.internal.Flattener;
import org.instancio.internal.nodes.InternalNode;
import org.jetbrains.annotations.NotNull;

import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * A selector map that contains {@link TargetSelector TargetSelectors} as the values.
 */
final class TargetSelectorSelectorMap {

    private final SelectorMap<List<TargetSelector>> selectorMap;

    TargetSelectorSelectorMap(@NotNull final Map<TargetSelector, List<TargetSelector>> targetSelectors) {
        this.selectorMap = targetSelectors.isEmpty() ? SelectorMapImpl.emptyMap() : new SelectorMapImpl<>();
        putAll(targetSelectors);
    }

    private void putAll(final Map<TargetSelector, List<TargetSelector>> map) {
        for (Map.Entry<TargetSelector, List<TargetSelector>> entry : map.entrySet()) {
            final TargetSelector targetSelector = entry.getKey();
            final List<TargetSelector> assignments = entry.getValue();

            for (TargetSelector selector : ((Flattener<TargetSelector>) targetSelector).flatten()) {
                selectorMap.put(selector, assignments);
            }
        }
    }

    SelectorMap<List<TargetSelector>> getSelectorMap() {
        return selectorMap;
    }

    List<TargetSelector> getTargetSelector(final InternalNode node) {
        return selectorMap.getValue(node).orElse(Collections.emptyList());
    }
}

==> instancio-core-4.2.0-sources.jar: org/instancio/internal/context/TargetSelectorSelectorMap.java <==
/*
 * Copyright 2022-2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.instancio.internal.context;

import org.instancio.TargetSelector;
import org.instancio.internal.nodes.InternalNode;
import org.jetbrains.annotations.NotNull;

import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * A selector map that contains {@link TargetSelector TargetSelectors} as the values.
 */
final class TargetSelectorSelectorMap {

    private final SelectorMap<List<TargetSelector>> selectorMap;

    TargetSelectorSelectorMap(@NotNull final Map<TargetSelector, List<TargetSelector>> targetSelectors) {
        this.selectorMap = targetSelectors.isEmpty() ? SelectorMapImpl.emptyMap() : new SelectorMapImpl<>();
        putAll(targetSelectors);
    }

    private void putAll(final Map<TargetSelector, List<TargetSelector>> map) {
        for (Map.Entry<TargetSelector, List<TargetSelector>> entry : map.entrySet()) {
            selectorMap.put(entry.getKey(), entry.getValue());
        }
    }

    SelectorMap<List<TargetSelector>> getSelectorMap() {
        return selectorMap;
    }

    List<TargetSelector> getTargetSelector(final InternalNode node) {
        return selectorMap.getValue(node).orElse(Collections.emptyList());
    }
}
